login.unisa.edu.au – University of South Australia

# login.unisa.edu.au

UniSA home

Directory

Email

myUniSA

Library

## Enter your UniSA Username and Password

Username:
Password:

## Welcome to `login.unisa.edu.au`

This is the web login service for UniSA web applications. This page will become more familiar as additional services throughout the University start using web single sign-on and federated access management. For more information checkout the Australian Access Federation.

## News:

``login'` is now the initial sign-on page for Shibboleth Federated Access at UniSA.

ATN eGradschool is the first service to utilise ``login'`. Course content is hosted by QUT for eGradSchool students Australia wide.

A list of testbed websites compatible with ``login'` are available via the Meta Access Management System (MAMS) website.

Help is available if you forgot your password.

For security reasons, please Log Out and Exit your web browser when you are done accessing services that require authentication!